Index: wp-includes/class-oembed.php
===================================================================
--- wp-includes/class-oembed.php	(revision 12883)
+++ wp-includes/class-oembed.php	(working copy)
@@ -52,8 +52,8 @@
 			'http://wordpress.tv/*'                 => array( 'http://wordpress.tv/oembed/',              false ),
 		) );
 
-		// Fix Scribd embeds. They contain new lines in the middle of the HTML which breaks wpautop().
-		add_filter( 'oembed_dataparse', array(&$this, 'strip_scribd_newlines'), 10, 3 );
+		// Fix Scribd and Viddler embeds. They contain new lines in the middle of the HTML which breaks wpautop().
+		add_filter( 'oembed_dataparse', array(&$this, 'strip_newlines'), 10, 3 );
 	}
 
 	/**
@@ -239,8 +239,8 @@
 	 * @param string $url The original URL passed to oEmbed.
 	 * @return string Possibly modified $html
 	 */
-	function strip_scribd_newlines( $html, $data, $url ) {
-		if ( preg_match( '#http://(www\.)?scribd.com/.*#i', $url ) )
+	function strip_newlines( $html, $data, $url ) {
+		if ( preg_match( '#http://(www\.)?scribd.com/.*#i', $url ) || preg_match( '#http://(www\.)?viddler\.com/.*#i', $url ) )
 			$html = str_replace( array( "\r\n", "\n" ), '', $html );
 
 		return $html;
